A Django app to transform and refine campaign-finance data from the California Secretary of State’s `CAL-ACCESS <http://www.sos.ca.gov/prd/cal-access/>`__ database

-  Documentation:
   `django-calaccess-processed-data.californiacivicdata.org <http://django-calaccess.californiacivicdata.org>`__
-  Issues:
   `github.com/california-civic-data-coalition/django-calaccess-processed-data/issues <https://github.com/california-civic-data-coalition/django-calaccess-processed-data/issues>`__
-  Packaging:
   `pypi.python.org/pypi/django-calaccess-processed-data <https://pypi.python.org/pypi/django-calaccess-processed-data>`__
-  Testing:
   `github.com/california-civic-data-coalition/django-calaccess-processed-data/actions <https://github.com/california-civic-data-coalition/django-calaccess-processed-data/actions/workflows/test.yaml>`__
